@@ -56,6 +56,9 @@ GType anjuta_command_queue_execute_mode_get_type (void) G_GNUC_CONST;
 /* enumerations from "anjuta-command-bar.h" */
 GType anjuta_command_bar_entry_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_COMMAND_BAR_ENTRY_TYPE (anjuta_command_bar_entry_type_get_type())
+/* enumerations from "anjuta-token.h" */
+GType anjuta_token_type_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_TOKEN_TYPE (anjuta_token_type_get_type())
 G_END_DECLS
 
 #endif /* __ANJUTA_ENUM_TYPES_H__ */
