@@ -919,7 +919,8 @@ create_plugin_tree (void)
 	gtk_tree_view_column_add_attribute (column, renderer, "pixbuf",
 										COL_ICON);
 	renderer = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (column, renderer, FALSE);
+	g_object_set(renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
+	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_add_attribute (column, renderer, "markup",
 										COL_NAME);
 	gtk_tree_view_column_set_sizing (column,
@@ -1145,26 +1146,40 @@ anjuta_plugin_manager_get_plugins_page (AnjutaPluginManager *plugin_manager)
 	GtkWidget *checkbutton;
 	GtkWidget *tree;
 	GtkWidget *scrolled;
+	GtkWidget *toolbar;
+	GtkWidget *toolitem;
 	GtkListStore *store;
 	
 	/* Plugins page */
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 10);
-	
-	checkbutton = gtk_check_button_new_with_label (dgettext (GETTEXT_PACKAGE, "Only show user activatable plugins"));
-	gtk_container_set_border_width (GTK_CONTAINER (checkbutton), 10);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), checkbutton, FALSE, FALSE, 0);
-	
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+
 	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
 									     GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-									GTK_POLICY_AUTOMATIC,
+									GTK_POLICY_NEVER,
 									GTK_POLICY_AUTOMATIC);
+	gtk_style_context_set_junction_sides (gtk_widget_get_style_context (scrolled), GTK_JUNCTION_BOTTOM);
 	gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
+
+	toolbar = gtk_toolbar_new ();
+	gtk_style_context_add_class (gtk_widget_get_style_context (toolbar), GTK_STYLE_CLASS_INLINE_TOOLBAR);
+	gtk_style_context_set_junction_sides (gtk_widget_get_style_context (toolbar), GTK_JUNCTION_TOP);
+	gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, FALSE, 0);
+	gtk_widget_show (toolbar);
+
+	toolitem = gtk_tool_item_new ();
+	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), GTK_TOOL_ITEM (toolitem), 0);
+	gtk_widget_show (toolitem);
+
+	checkbutton = gtk_check_button_new_with_label (dgettext (GETTEXT_PACKAGE, "Only show user activatable plugins"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), TRUE);
+	gtk_container_add (GTK_CONTAINER (toolitem), checkbutton);
 	
 	tree = create_plugin_tree ();
+	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
+	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (tree)));
 
 	populate_plugin_model (plugin_manager, store, NULL,
