@@ -508,8 +508,15 @@ dir_project_load_directory_callback (GObject      *source_object,
 					g_object_unref (remove);
 				}
 			}
-			anjuta_project_node_clear_state (data->parent, ANJUTA_PROJECT_INCOMPLETE);
-			g_signal_emit_by_name (data->proj, "node-loaded", data->parent, NULL);
+			if (anjuta_project_node_parent (data->parent) == data->proj->root)
+			{
+				/* Emit signal on root node instead of the first group */
+				g_signal_emit_by_name (data->proj, "node-loaded", data->proj->root, NULL);
+			}
+			else
+			{
+				g_signal_emit_by_name (data->proj, "node-loaded", data->parent, NULL);
+			}
 		}
 		g_object_unref (data->parent);
 		g_slice_free (DirData, data);
@@ -795,6 +802,22 @@ dir_project_get_node_info (DirProject *project, GError **error)
 	return info_list;
 }
 
+static gboolean
+find_not_loaded_node (gpointer key, gpointer value, gpointer user_data)
+{
+	AnjutaProjectNode *node = (AnjutaProjectNode *)value;
+	gboolean found;
+	
+	found = anjuta_project_node_get_state (node) & (ANJUTA_PROJECT_LOADING | ANJUTA_PROJECT_INCOMPLETE);
+
+	return found;
+}
+ 
+static gboolean
+dir_project_is_loaded (DirProject *project)
+{
+	return g_hash_table_find (project->groups, find_not_loaded_node, NULL) == NULL;
+}
 
 /* Public functions
  *---------------------------------------------------------------------------*/
@@ -818,7 +841,6 @@ static gboolean
 iproject_load_node (IAnjutaProject *obj, AnjutaProjectNode *node, GError **err)
 {
 	node = dir_project_load_node (DIR_PROJECT (obj), node, err);
-	g_signal_emit_by_name (obj, "node-loaded", node, NULL);
 
 	return node != NULL;
 }
@@ -901,6 +923,12 @@ iproject_get_node_info (IAnjutaProject *obj, GError **err)
 	return dir_project_get_node_info (DIR_PROJECT (obj), err);
 }
 
+static gboolean
+iproject_is_loaded (IAnjutaProject *obj, GError **err)
+{
+	return dir_project_is_loaded (DIR_PROJECT (obj));
+}
+
 static void
 iproject_iface_init(IAnjutaProjectIface* iface)
 {
@@ -913,6 +941,7 @@ iproject_iface_init(IAnjutaProjectIface* iface)
 	iface->remove_property = iproject_remove_property;
 	iface->get_root = iproject_get_root;
 	iface->get_node_info = iproject_get_node_info;
+	iface->is_loaded = iproject_is_loaded;
 }
 
 /* GbfProject implementation
