@@ -436,6 +436,7 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 	GtkWidget* entry;
 	NPWDruidAddPropertyData* data = (NPWDruidAddPropertyData *)user_data;
 	const gchar* description;
+	GtkAttachOptions attach = GTK_EXPAND|GTK_FILL;
 
 
 	entry = npw_property_create_widget (property);
@@ -455,7 +456,7 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 		gtk_misc_set_padding (GTK_MISC (label), 6, 6);
 		
 		switch (npw_property_get_type (property))
-		{
+		{				
 			case NPW_PACKAGE_PROPERTY:
 				gtk_table_resize (data->table, data->row + 2, 1);
 				gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
@@ -465,13 +466,16 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 				                  (GtkAttachOptions)(GTK_EXPAND|GTK_FILL), 0, 0);
 				data->row += 2;
 				break;
+			case NPW_BOOLEAN_PROPERTY:
+				attach = 0;
+				/* Fall through */
 			default:
 				/* Add label and entry */
 				gtk_table_resize (data->table, data->row + 1, 2);
 				gtk_table_attach (data->table, label, 0, 1, data->row, data->row + 1,
 				                  (GtkAttachOptions)(GTK_FILL), 0, 0, 0);
 				gtk_table_attach (data->table, entry, 1, 2, data->row, data->row + 1,
-				                  (GtkAttachOptions)(GTK_EXPAND|GTK_FILL), 0, 0, 0);
+				                  (GtkAttachOptions)(attach), 0, 0, 0);
 				data->row++;
 		}
 		
@@ -639,12 +643,12 @@ cb_save_valid_property (NPWProperty* property, gpointer user_data)
 		{
 		case NPW_FILENAME_RESTRICTION:
 			g_string_append_printf (data->error,
-									_("Field \"%s\" must contains only letters, digits or the following characters \"#$:%+,.=@^_`~\". In addition you cannot have a leading dash. Please fix it."),
+									_("Field \"%s\" must contains only letters, digits or the following characters \"#$:%%+,.=@^_`~\". In addition you cannot have a leading dash. Please fix it."),
 									npw_property_get_label (property));
 			break;
 		case NPW_DIRECTORY_RESTRICTION:
 			g_string_append_printf (data->error,
-									_("Field \"%s\" must contains only letters, digits, the following characters \"#$:%+,.=@^_`~\" or directory separators. In addition you cannot have a leading dash. Please fix it."),
+									_("Field \"%s\" must contains only letters, digits, the following characters \"#$:%%+,.=@^_`~\" or directory separators. In addition you cannot have a leading dash. Please fix it."),
 									npw_property_get_label (property));
 			break;
 		default:
@@ -805,9 +809,16 @@ on_druid_get_new_page (NPWAutogen* gen, gpointer data)
 static void
 on_druid_parse_page (const gchar* output, gpointer data)
 {
+	GError *error = NULL;
 	NPWPageParser* parser = (NPWPageParser*)data;
 	
-	npw_page_parser_parse (parser, output, strlen (output), NULL);
+	npw_page_parser_parse (parser, output, strlen (output), &error);
+
+	if (error)
+	{
+		g_warning ("Parser error: %s", error->message);
+		g_error_free (error);
+	}
 }
 
 static void
@@ -914,7 +925,7 @@ check_and_warn_missing (NPWDruid *druid)
 
 		npw_druid_fill_error_page (druid, hbox,
 								   GTK_MESSAGE_WARNING,
-								  _("The missing programs are usually part of some distrubution "
+								  _("The missing programs are usually part of some distribution "
 									"packages and can be searched for in your Application Manager. "
 									"Similarly, the development packages are contained in special "
 									"packages that your distribution provides to allow development "
@@ -1091,6 +1102,9 @@ npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 	
 	/* Add dialog widget to anjuta status. */
 	anjuta_status_add_widget (anjuta_shell_get_status (shell, NULL), GTK_WIDGET (assistant));
+
+	gtk_window_set_default_size (GTK_WINDOW (assistant),
+	                             600, 500);
 	
 	gtk_widget_show_all (GTK_WIDGET (assistant));
 	
