@@ -147,7 +147,13 @@ on_help_advanced_tutorial_activate (GtkAction *action, gpointer data)
 void
 on_help_faqs_activate (GtkAction *action, gpointer data)
 {
-	help_activate (data, "anjuta-faqs", "anjuta-faqs.xml");
+	GError* error = NULL;
+	if (!g_spawn_command_line_async ("yelp ghelp:anjuta-faqs", &error) &&
+	    error)
+	{
+		g_warning ("Could open FAQ: %s", error->message);
+		g_error_free (error);
+	}
 }
 
 void
@@ -159,7 +165,7 @@ on_url_home_activate (GtkAction * action, gpointer user_data)
 void
 on_url_bugs_activate (GtkAction * action, gpointer user_data)
 {
-	anjuta_res_url_show("http://bugzilla.gnome.org/simple-bug-guide.cgi");
+	anjuta_res_url_show("https://bugzilla.gnome.org/enter_bug.cgi?product=anjuta");
 }
 
 void
@@ -169,9 +175,9 @@ on_url_faqs_activate (GtkAction * action, gpointer user_data)
 }
 
 void
-on_about_activate (GtkAction * action, gpointer user_data)
-{
-	GtkWidget *about_dlg = about_box_new ();
+on_about_activate (GtkAction * action, AnjutaApp *app)
+{	
+	GtkWidget *about_dlg = about_box_new (GTK_WINDOW (app));
 
 	g_signal_connect_swapped(about_dlg, "response",
 		G_CALLBACK(gtk_widget_destroy), about_dlg);
